@@ -1,8 +1,6 @@
-/* fmfconv_wav.c: wav output routine included into fmfconv.c
+/* fmfconv_au.c: au output routine included into fmfconv.c
    Copyright (c) 2004-2015 Gergely Szasz
 
-   $Id: fmfconv_au.c 5424 2016-04-29 13:27:54Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -35,7 +33,7 @@ static int
 snd_write_auheader( void )
 {
   const char str[] =
-    "fmfconv created AU file (http://fuse-emulator.sourceforge.net)\n";
+    "ZX Spectrum audio created by fmfconv: http://fuse-emulator.sourceforge.net/";
   size_t len = sizeof(str); /* Includes the null terminator */
   int padding = len % 8;
   libspectrum_dword buff[6];
