@@ -1,8 +1,6 @@
 /* fmfconv_ppm.c: ppm output routine included into fmfconv.c
    Copyright (c) 2004-2015 Gergely Szasz
 
-   $Id: fmfconv_ppm.c 5424 2016-04-29 13:27:54Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -36,8 +34,8 @@ int
 out_write_ppm( void )
 {
   fprintf( out, ( greyscale ? "P5\n" : "P6\n" ) );
-  fprintf( out, "#ZX Spectrum screenshot created by fmfconv "
-           "(http://fuse-emulator.sourceforge.net)\n"
+  fprintf( out, "#ZX Spectrum screenshot created by fmfconv: "
+           "http://fuse-emulator.sourceforge.net/\n"
            "%u %u 255\n", frm_w, frm_h );
 
   if( fwrite( pix_rgb, frm_w * frm_h * ( greyscale ? 1 : 3 ), 1, out ) != 1 )
